aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/area
diff options
context:
space:
mode:
authorWilliam Victor Mote <vmote@apache.org>2003-09-10 18:42:22 +0000
committerWilliam Victor Mote <vmote@apache.org>2003-09-10 18:42:22 +0000
commitc070baf45dffa82018c856a1bde21a144c181cae (patch)
treea6a54759bc41e55070797f18b793b3c1953b3b81 /src/java/org/apache/fop/area
parent180e00d9932248dd29cf572fb3b8e81df847c422 (diff)
downloadxmlgraphics-fop-c070baf45dffa82018c856a1bde21a144c181cae.tar.gz
xmlgraphics-fop-c070baf45dffa82018c856a1bde21a144c181cae.zip
add InlineAreaVisitor interface to make Area Tree more independent of Rendering
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@196900 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org/apache/fop/area')
-rw-r--r--src/java/org/apache/fop/area/inline/Character.java31
-rw-r--r--src/java/org/apache/fop/area/inline/InlineArea.java31
-rw-r--r--src/java/org/apache/fop/area/inline/InlineAreaVisitor.java103
-rw-r--r--src/java/org/apache/fop/area/inline/InlineParent.java30
-rw-r--r--src/java/org/apache/fop/area/inline/Leader.java31
-rw-r--r--src/java/org/apache/fop/area/inline/Space.java32
-rw-r--r--src/java/org/apache/fop/area/inline/Viewport.java30
-rw-r--r--src/java/org/apache/fop/area/inline/Word.java31
8 files changed, 210 insertions, 109 deletions
diff --git a/src/java/org/apache/fop/area/inline/Character.java b/src/java/org/apache/fop/area/inline/Character.java
index 2135162e6..e1eacd682 100644
--- a/src/java/org/apache/fop/area/inline/Character.java
+++ b/src/java/org/apache/fop/area/inline/Character.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,16 +42,14 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
-import org.apache.fop.render.Renderer;
-
/**
* Single character inline area.
* This inline area holds a single character.
@@ -69,12 +67,13 @@ public class Character extends InlineArea {
}
/**
- * Render this inline area.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this character area
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderCharacter(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
/**
diff --git a/src/java/org/apache/fop/area/inline/InlineAreaVisitor.java b/src/java/org/apache/fop/area/inline/InlineAreaVisitor.java
new file mode 100644
index 000000000..35e7a4a42
--- /dev/null
+++ b/src/java/org/apache/fop/area/inline/InlineAreaVisitor.java
@@ -0,0 +1,103 @@
+/*
+ * $Id$
+ * ============================================================================
+ * The Apache Software License, Version 1.1
+ * ============================================================================
+ *
+ * Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without modifica-
+ * tion, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ * this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ *
+ * 3. The end-user documentation included with the redistribution, if any, must
+ * include the following acknowledgment: "This product includes software
+ * developed by the Apache Software Foundation (http://www.apache.org/)."
+ * Alternately, this acknowledgment may appear in the software itself, if
+ * and wherever such third-party acknowledgments normally appear.
+ *
+ * 4. The names "FOP" and "Apache Software Foundation" must not be used to
+ * endorse or promote products derived from this software without prior
+ * written permission. For written permission, please contact
+ * apache@apache.org.
+ *
+ * 5. Products derived from this software may not be called "Apache", nor may
+ * "Apache" appear in their name, without prior written permission of the
+ * Apache Software Foundation.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
+ * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * APACHE SOFTWARE FOUNDATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
+ * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLU-
+ * DING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
+ * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+ * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * ============================================================================
+ *
+ * This software consists of voluntary contributions made by many individuals
+ * on behalf of the Apache Software Foundation and was originally created by
+ * James Tauber <jtauber@jtauber.com>. For more information on the Apache
+ * Software Foundation, please see <http://www.apache.org/>.
+ */
+package org.apache.fop.area.inline;
+
+/**
+ * <p>Implements the GoF Visitor design pattern to allow access to inline areas
+ * without knowing what subclass of InlineArea is being accessed. This is used
+ * primarily to keep the area tree classes isolated from any classes (typically
+ * renderers) that might need access to them.</p>
+ */
+public interface InlineAreaVisitor {
+
+ /**
+ * Handle a visitor request to process an inline viewport.
+ *
+ * @param viewport The viewport area
+ */
+ void serveVisitor(Viewport viewport);
+
+ /**
+ * Handle a visitor request to process an inline word.
+ *
+ * @param area The word area
+ */
+ void serveVisitor(Word area);
+
+ /**
+ * Handle a visitor request to process an inline parent area.
+ *
+ * @param ip The inline parent area
+ */
+ void serveVisitor(InlineParent ip);
+
+ /**
+ * Handle a visitor request to process an inline character.
+ *
+ * @param ch The inline character
+ */
+ void serveVisitor(org.apache.fop.area.inline.Character ch);
+
+ /**
+ * Handle a visitor request to process an inline space.
+ *
+ * @param space The inline space
+ */
+ void serveVisitor(Space space);
+
+ /**
+ * Handle a visitor request to process an inline leader area.
+ *
+ * @param area The inline leader area.
+ */
+ void serveVisitor(Leader area);
+
+}
diff --git a/src/java/org/apache/fop/area/inline/InlineParent.java b/src/java/org/apache/fop/area/inline/InlineParent.java
index 8b79f15cb..e8f93c3f8 100644
--- a/src/java/org/apache/fop/area/inline/InlineParent.java
+++ b/src/java/org/apache/fop/area/inline/InlineParent.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,16 +42,15 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
import org.apache.fop.area.Area;
-import org.apache.fop.render.Renderer;
import java.util.List;
import java.util.ArrayList;
@@ -78,12 +77,13 @@ public class InlineParent extends InlineArea {
}
/**
- * Render this area.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this area in
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderInlineParent(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
/**
diff --git a/src/java/org/apache/fop/area/inline/Leader.java b/src/java/org/apache/fop/area/inline/Leader.java
index 6f045510b..dd503bcd8 100644
--- a/src/java/org/apache/fop/area/inline/Leader.java
+++ b/src/java/org/apache/fop/area/inline/Leader.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,15 +42,14 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
-import org.apache.fop.render.Renderer;
import org.apache.fop.fo.properties.RuleStyle;
/**
@@ -110,12 +109,14 @@ public class Leader extends InlineArea {
}
/**
- * Render this leader in the current renderer.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this inline area
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderLeader(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
+
}
diff --git a/src/java/org/apache/fop/area/inline/Space.java b/src/java/org/apache/fop/area/inline/Space.java
index a4391d6af..92095eb82 100644
--- a/src/java/org/apache/fop/area/inline/Space.java
+++ b/src/java/org/apache/fop/area/inline/Space.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,16 +42,14 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
-import org.apache.fop.render.Renderer;
-
/**
* Inline space area.
* This is used for adding a inline space to the output.
@@ -59,11 +57,13 @@ import org.apache.fop.render.Renderer;
public class Space extends InlineArea {
/**
- * Render this inlien space area.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this inline area
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderInlineSpace(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
+
}
diff --git a/src/java/org/apache/fop/area/inline/Viewport.java b/src/java/org/apache/fop/area/inline/Viewport.java
index e9a736d4b..6c01afb3f 100644
--- a/src/java/org/apache/fop/area/inline/Viewport.java
+++ b/src/java/org/apache/fop/area/inline/Viewport.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,16 +42,15 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
import org.apache.fop.area.Area;
-import org.apache.fop.render.Renderer;
import java.io.IOException;
import java.awt.geom.Rectangle2D;
@@ -126,12 +125,13 @@ public class Viewport extends InlineArea {
}
/**
- * Render this inline area.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this inline area
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderViewport(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
private void writeObject(java.io.ObjectOutputStream out)
diff --git a/src/java/org/apache/fop/area/inline/Word.java b/src/java/org/apache/fop/area/inline/Word.java
index 2977c3310..462cf0bc3 100644
--- a/src/java/org/apache/fop/area/inline/Word.java
+++ b/src/java/org/apache/fop/area/inline/Word.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,16 +42,14 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
-import org.apache.fop.render.Renderer;
-
/**
* A word inline area.
* This is really a collection character inline areas collected together
@@ -71,12 +69,13 @@ public class Word extends InlineArea {
}
/**
- * Render the word to the renderer.
+ * Handle InlineAreaVisitor request by passing this back to it.
*
- * @param renderer the renderer to render this word
+ * @param visitor the InlineAreaVisitor wishing to process this.
+ * @see org.apache.fop.area.inline.InlineAreaVisitor
*/
- public void render(Renderer renderer) {
- renderer.renderWord(this);
+ public void acceptVisitor(InlineAreaVisitor visitor) {
+ visitor.serveVisitor(this);
}
/**
diff --git a/src/java/org/apache/fop/area/inline/InlineArea.java b/src/java/org/apache/fop/area/inline/InlineArea.java
index 572f69b3c..87e4207ff 100644
--- a/src/java/org/apache/fop/area/inline/InlineArea.java
+++ b/src/java/org/apache/fop/area/inline/InlineArea.java
@@ -3,34 +3,34 @@
* ============================================================================
* The Apache Software License, Version 1.1
* ============================================================================
- *
+ *
* Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
- *
+ *
* Redistribution and use in source and binary forms, with or without modifica-
* tion, are permitted provided that the following conditions are met:
- *
+ *
* 1. Redistributions of source code must retain the above copyright notice,
* this list of conditions and the following disclaimer.
- *
+ *
* 2. Redistributions in binary form must reproduce the above copyright notice,
* this list of conditions and the following disclaimer in the documentation
* and/or other materials provided with the distribution.
- *
+ *
* 3. The end-user documentation included with the redistribution, if any, must
* include the following acknowledgment: "This product includes software
* developed by the Apache Software Foundation (http://www.apache.org/)."
* Alternately, this acknowledgment may appear in the software itself, if
* and wherever such third-party acknowledgments normally appear.
- *
+ *
* 4. The names "FOP" and "Apache Software Foundation" must not be used to
* endorse or promote products derived from this software without prior
* written permission. For written permission, please contact
* apache@apache.org.
- *
+ *
* 5. Products derived from this software may not be called "Apache", nor may
* "Apache" appear in their name, without prior written permission of the
* Apache Software Foundation.
- *
+ *
* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
* FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
@@ -42,17 +42,16 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* ============================================================================
- *
+ *
* This software consists of voluntary contributions made by many individuals
* on behalf of the Apache Software Foundation and was originally created by
* James Tauber <jtauber@jtauber.com>. For more information on the Apache
* Software Foundation, please see <http://www.apache.org/>.
- */
+ */
package org.apache.fop.area.inline;
import org.apache.fop.area.Area;
import org.apache.fop.area.Trait;
-import org.apache.fop.render.Renderer;
import org.apache.fop.traits.BorderProps;
/**
@@ -76,14 +75,14 @@ public class InlineArea extends Area {
protected int verticalPosition = 0;
/**
- * Render this inline area.
+ * Handle a visitor (usually a renderer) for this inline area.
* Inline areas that extend this class are expected
- * to implement this method to render themselves in
- * the renderer.
+ * to pass themselves back to the visitor so that the visitor can process
+ * them, usually by rendering them.
*
* @param renderer the renderer to render this inline area
*/
- public void render(Renderer renderer) {
+ public void acceptVisitor(InlineAreaVisitor visitor) {
}
/**
@@ -76,14 +75,14 @@ public class InlineArea extends Area {
*
- * @param renderer the renderer to render this inline area
+ * @param visitor the InlineAreaVisitor that will process this
*/